//= require <dialogs/default.js>
//= require <util.js>

Ext.namespace('dSA', 'dSA.actions', 'dSA.util', 'dSA.dialogs',
              'dSA.actions.dsmsettings');

dSA.actions.dsmsettings.LockRegistration = Ext.extend(Ext.Panel, {
    constructor: function(config) {
        this.dsid = config.dsid;

        Ext.apply(this, {
            padding: 5,
            scope: this,
            bubbleEvents: [ 'datasaved' ],
            items:
            [
                {
                    xtype: 'checkbox',
                    ref: 'registration',
                    boxLabel: dSA._("Disable registration of new devices"),
                    name: 'registration_' + config.dsid
                }            
            ]
        });

        dSA.actions.dsmsettings.LockRegistration.superclass.constructor.apply(
                this, arguments);

        this.on('afterrender',
            function()
            {
                this.el.mask(dSA._("Loading") + '...', 'x-mask-loading');
                dSA.functions.LoadRegistrationMode(this.dsid, 
                            this.regModeLoadCallback.createDelegate(this));
            },
            this);
        this.on('savepressed',
            function()
            {
                this.el.mask(dSA._("Saving") + '...', 'x-mask-loading');
                var action = 'no';
                if (this.registration.getValue() == true)
                {
                    action = 'yes';
                }

                dSA.functions.SetRegistrationMode(this.dsid, action,
                    this.regModeSaveCallback.createDelegate(this, [ action ],
                                                            true));
            },
            this);
    },
    regModeLoadCallback: function(result, data)
    {
        if (result == false)
        {
            this.el.unmask();
            return;
        }
        this.el.unmask();
        if (!data)
        {
            this.registration.markInvalid(dSA._("Could not load settings"));
        }

        this.registration.setValue(!data.actionsfromnewdevicesenabled);
    },
    regModeSaveCallback: function(result, action)
    {
        this.fireEvent('datasaved');
        if (result === true)
        {
            if (dSS.module === true)
            {
                dSS.MessageBus.fireEvent('updatedsmdignoredevflag', this.dsid,
                                         (action === 'yes'));
            }
        }
    }
});

dSA.actions.dsmsettings.ShowdSMSettingsDialog = function(dsid, name, maskEl)
{
    var regform = new dSA.actions.dsmsettings.LockRegistration({ dsid: dsid });
    var savebutton = new Ext.Button({
        text: dSA._("Save"),
        handler: function()
        {
            regform.fireEvent('savepressed');
        }
    });

    var win = new dSA.dialogs.DefaultDialogWindow(
    {
        title: dSA._("dSM settings"),
        name: name,
        device: false,
        dsid: dsid,
        maskElement: maskEl,
        extraItems: [ regform ],
        buttons: [ savebutton ]
    });
    win.on('datasaved',
        function()
        {
            maskEl.unmask();
            win.close();
        });

    win.show();
};
